@@ -202,6 +202,10 @@ class HamsterApplet(object):
 
         self.new_name = widgets.ActivityEntry()
         self.new_name.connect("value-entered", self.on_switch_activity_clicked)
+
+        self.new_name.set_property("secondary-icon-name", "help")
+        self.new_name.connect("icon-press", self.on_more_info_button_clicked)
+
         widgets.add_hint(self.new_name, _("Activity"))
         self.get_widget("new_name_box").add(self.new_name)
         self.new_name.connect("changed", self.on_activity_text_changed)
@@ -333,7 +337,6 @@ class HamsterApplet(object):
         facts = runtime.storage.get_todays_facts()
 
         self.treeview.detach_model()
-        self.treeview.clear()
 
         if facts and facts[-1]["end_time"] == None:
             self.last_activity = facts[-1]
@@ -396,8 +399,6 @@ class HamsterApplet(object):
                 self.get_widget("last_activity_name").set_text(activity['name'])
 
 
-            self._gui.get_object("more_info_button").hide()
-
             self.get_widget("last_activity_duration").set_text(stuff.format_duration(duration) or _("Just started"))
             self.get_widget("last_activity_description").set_text(activity['description'] or "")
             self.get_widget("activity_info_box").show()
@@ -410,8 +411,6 @@ class HamsterApplet(object):
             self.get_widget("last_activity_name").set_text(_("No activity"))
 
             self.get_widget("activity_info_box").hide()
-            self._gui.get_object("more_info_button").show()
-
             self.tag_box.draw([])
 
 
@@ -423,7 +422,7 @@ class HamsterApplet(object):
         """main window display and positioning"""
         self.button.set_active(is_active)
 
-        if not is_active:
+        if is_active == False:
             self.window.hide()
             return True
 
@@ -527,8 +526,8 @@ class HamsterApplet(object):
 
     """button events"""
     def on_overview(self, menu_item):
-        self.__show_toggle(False)
         dialogs.overview.show(self.applet)
+        self.__show_toggle(False)
 
     def show_overview(self, menu_item, verb):
         return self.on_overview(menu_item)
@@ -537,11 +536,11 @@ class HamsterApplet(object):
         dialogs.edit.show(self.applet)
 
     def on_about (self, component, verb):
-        dialogs.about.show()
+        dialogs.about.show(self.window)
 
     def show_preferences(self, menu_item, verb):
-        self.__show_toggle(False)
         dialogs.prefs.show(self.applet)
+        self.__show_toggle(False)
 
 
     """signals"""
@@ -696,5 +695,5 @@ class HamsterApplet(object):
         return self._gui.get_object(name)
 
     def on_more_info_button_clicked(self, *args):
-        gtk.show_uri(gtk.gdk.Screen(), "ghelp:hamster-applet", 0L)
+        gtk.show_uri(gtk.gdk.Screen(), "ghelp:hamster-applet#input", 0L)
         return False
