@@ -31,38 +31,9 @@ import datetime as dt
 import calendar
 import time
 import re
-import gettext, locale
+import locale
 import os
 
-def setup_i18n():
-    #determine location of po files
-    try:
-        import defs
-    except:
-        defs = None
-
-
-    # to avoid confusion, we won't translate unless running installed
-    # reason for that is that bindtextdomain is expecting
-    # localedir/language/LC_MESSAGES/domain.mo format, but we have
-    # localedir/language.mo at it's best (after build)
-    # and there does not seem to be any way to run straight from sources
-    if defs:
-        locale_dir = os.path.realpath(os.path.join(defs.DATA_DIR, "locale"))
-
-        for module in (locale,):
-            module.bindtextdomain('hamster-applet', locale_dir)
-            module.textdomain('hamster-applet')
-
-            module.bind_textdomain_codeset('hamster-applet','utf8')
-
-        gettext.install("hamster-applet", locale_dir, unicode = True)
-
-    else:
-        gettext.install("hamster-applet-uninstalled")
-
-
-
 def format_duration(minutes, human = True):
     """formats duration in a human readable format.
     accepts either minutes or timedelta"""
@@ -147,7 +118,16 @@ def month(view_date):
 
 def duration_minutes(duration):
     """returns minutes from duration, otherwise we keep bashing in same math"""
-    return duration.seconds / 60 + duration.days * 24 * 60
+    if isinstance(duration, list):
+        res = dt.timedelta()
+        for entry in duration:
+            res += entry
+
+        return duration_minutes(res)
+    elif isinstance(duration, dt.timedelta):
+        return duration.seconds / 60 + duration.days * 24 * 60
+    else:
+        return duration
 
 
 def load_ui_file(name):
@@ -193,33 +173,6 @@ def locale_first_weekday():
 
     return first_weekday
 
-class CategoryCell(gtk.CellRendererText):
-    def __init__(self):
-        gtk.CellRendererText.__init__(self)
-        self.set_property('alignment', pango.ALIGN_RIGHT)
-
-        insensitive_color = gtk.Label().style.fg[gtk.STATE_INSENSITIVE]
-        self.set_property('foreground-gdk', insensitive_color)
-        self.set_property('scale', pango.SCALE_SMALL)
-        self.set_property('yalign', 0.0)
-
-
-insensitive_color = gtk.Label().style.fg[gtk.STATE_INSENSITIVE].to_string()
-def format_activity(name, category, description, pad_description = False):
-    "returns pango markup for activity with category and description"
-    text = name
-    if category and category != _("Unsorted"):
-        text += """ - <span color="%s" size="x-small">%s</span>""" % (insensitive_color, category)
-
-    if description:
-        text+= "\n"
-        if pad_description:
-            text += " " * 23
-
-        text += """<span style="italic" size="small">%s</span>""" % description
-
-    return text
-
 
 def totals(iter, keyfunc, sumfunc):
     """groups items by field described in keyfunc and counts totals using value
@@ -234,8 +187,6 @@ def totals(iter, keyfunc, sumfunc):
     return res
 
 
-
-
 def dateDict(date, prefix = ""):
     """converts date into dictionary, having prefix for all the keys"""
     res = {}
